@@ -50,8 +50,7 @@ def splitBAM(path_to_bam: str, n_parts: int) -> None:
         [os.path.join(path_to_bash_scripts, 'bin', 'splitBAM.sh'),
          bam_dir,
          bam_file,
-         str(part_size)],
-         shell=True
+         str(part_size)]
     )
     
 def mergeBAMs(bam_files_dir: str, output_path: str) -> None:
@@ -60,10 +59,8 @@ def mergeBAMs(bam_files_dir: str, output_path: str) -> None:
     """
     subprocess.run(
         [os.path.join(path_to_bash_scripts, 'bin', 'mergeBAMs.sh'),
-         bam_files_dir],
-         shell=True
+         bam_files_dir]
     )
-    
     os.rename(os.path.join(bam_files_dir, 'merged.bam'), output_path)
 
 def parallelizeBAMoperation(path_to_bam: str,
@@ -96,7 +93,6 @@ def parallelizeBAMoperation(path_to_bam: str,
     
     processes = []
     for n in range(n_processes):
-        
         p_input_path = os.path.join(chunks_dir, f'{n + 1}.bam')
         p_output_path = os.path.join(processed_chunks_dir, f'out{n + 1}.bam')
         
@@ -104,9 +100,11 @@ def parallelizeBAMoperation(path_to_bam: str,
         processes.append(
             Process(target=callback, args=cb_args)
         )
-        processes[-1].start()
-        processes[-1].join()
-
+    for p in processes:
+        p.start()   
+    for p in processes:
+        p.join()
+   
     mergeBAMs(processed_chunks_dir, output_path)
     
     shutil.rmtree(processed_chunks_dir, ignore_errors=True)
